==> tigre_1.2.1.zip: tigre/doc/tigre_quick.R <==
###################################################
### chunk number 1: 
###################################################
options(width = 60)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("tigre")


###################################################
### chunk number 3: 
###################################################
library(tigre)


###################################################
### chunk number 4:  eval=FALSE
###################################################
## # Names of CEL files
## expfiles <- c(paste("embryo_tc_4_", 1:12, ".CEL", sep=""),
##               paste("embryo_tc_6_", 1:12, ".CEL", sep=""),
##               paste("embryo_tc_8_", 1:12, ".CEL", sep=""))
## # Load the CEL files
## expdata <- ReadAffy(filenames=expfiles,
##                     celfile.path="embryo_tc_array_data")
## # Setup experimental data (observation times)
## pData(expdata) <- data.frame("time.h" = rep(1:12, 3),
##                              row.names=rownames(pData(expdata)))
## # Run mmgMOS processing (requires several minutes to complete)
## drosophila_mmgmos_exprs <- mmgmos(expdata)
## drosophila_mmgmos_fragment <- drosophila_mmgmos_exprs


###################################################
### chunk number 5:  eval=FALSE
###################################################
## drosophila_gpsim_fragment <-
##   processData(drosophila_mmgmos_fragment,
##               experiments=rep(1:3, each=12))


###################################################
### chunk number 6: 
###################################################
data(drosophila_gpsim_fragment)


###################################################
### chunk number 7: 
###################################################
# The probe identifier for TF 'twi'
twi <- "143396_at"
# The probe identifier for the target gene
target <- "152715_at"

# Learn the model using only one of the 3 repeats in the data
model <- GPLearn(drosophila_gpsim_fragment[,1:12],
                 TF=twi, targets=target,
                 useGpdisim=TRUE, quiet=TRUE)

# Display the model parameters
show(model)


###################################################
### chunk number 8:  eval=FALSE
###################################################
## GPPlot(model)


###################################################
### chunk number 9: 
###################################################
GPPlot(model)

==> tigre_1.4.2.zip: tigre/doc/tigre_quick.R <==
###################################################
### chunk number 1: 
###################################################
#line 43 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
options(width = 60)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("tigre")


###################################################
### chunk number 3: 
###################################################
#line 74 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
library(tigre)


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 91 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
## # Names of CEL files
## expfiles <- c(paste("embryo_tc_4_", 1:12, ".CEL", sep=""),
##               paste("embryo_tc_6_", 1:12, ".CEL", sep=""),
##               paste("embryo_tc_8_", 1:12, ".CEL", sep=""))
## # Load the CEL files
## expdata <- ReadAffy(filenames=expfiles,
##                     celfile.path="embryo_tc_array_data")
## # Setup experimental data (observation times)
## pData(expdata) <- data.frame("time.h" = rep(1:12, 3),
##                              row.names=rownames(pData(expdata)))
## # Run mmgMOS processing (requires several minutes to complete)
## drosophila_mmgmos_exprs <- mmgmos(expdata)
## drosophila_mmgmos_fragment <- drosophila_mmgmos_exprs


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 109 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
## drosophila_gpsim_fragment <-
##   processData(drosophila_mmgmos_fragment,
##               experiments=rep(1:3, each=12))


###################################################
### chunk number 6: 
###################################################
#line 120 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
data(drosophila_gpsim_fragment)


###################################################
### chunk number 7: 
###################################################
#line 128 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
# The probe identifier for TF 'twi'
twi <- "143396_at"
# The probe identifier for the target gene
target <- "152715_at"

# Learn the model using only one of the 3 repeats in the data
model <- GPLearn(drosophila_gpsim_fragment[,1:12],
                 TF=twi, targets=target,
                 useGpdisim=TRUE, quiet=TRUE)

# Display the model parameters
show(model)


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 146 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
## GPPlot(model)


###################################################
### chunk number 9: 
###################################################
#line 153 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpW6eH2e/R.INSTALL6fad307a/tigre/inst/doc/tigre_quick.Rnw"
GPPlot(model)
